@@ -25,7 +25,7 @@ class DltkAiClient:
                 DltkAiClient: Client object for DltkAi.
         """
         self.api_key = api_key
-        self.base_url = "https://dev-kong.dltk.ai"
+        self.base_url = "https://prod-kong.dltk.ai"
 
     def sentiment_analysis(self, text):
         """
@@ -218,7 +218,7 @@ class DltkAiClient:
         """
         body = {'image': (image_path, open(image_path, 'rb'), 'multipart/form-data')}
         payload = {'sources':sources}
-        url = 'https://dev-kong.dltk.ai/core/vision/face-detection/compare'
+        url =  self.base_url + '/core/vision/face-detection/compare'
         headers = {'ApiKey': self.api_key}
         response = requests.post(url=url, files=body, headers=headers,data=payload)
         return response
@@ -331,7 +331,7 @@ class DltkAiClient:
         """
         body = {'image': (image_path, open(image_path, 'rb'), 'multipart/form-data')}
         payload = {'sources':sources}
-        url = 'https://dev-kong.dltk.ai/core/vision/object-detection/image/compare'
+        url = self.base_url + '/core/vision/object-detection/image/compare'
         headers = {'ApiKey': self.api_key}
         response = requests.post(url=url, files=body, headers=headers,data=payload)
         return response
@@ -356,7 +356,7 @@ class DltkAiClient:
         """
         body = {'image': (image_path, open(image_path, 'rb'), 'multipart/form-data')}
         payload = {'sources':sources}
-        url = 'https://dev-kong.dltk.ai/core/vision/image-classification/compare'
+        url = self.base_url + '/core/vision/image-classification/compare'
         headers = {'ApiKey': self.api_key}
         response = requests.post(url=url, files=body, headers=headers,data=payload)
         return response
@@ -564,11 +564,27 @@ class DltkAiClient:
         """
         body = {'body': text}
         body = json.dumps(body)
-        url = self.base_url + '/text_to_voice_ai/'
+        url = self.base_url + '/text-to-speech/'
         headers = {'ApiKey': self.api_key, 'Content-Type': 'application/json'}
         response = requests.post(url=url, data=body, headers=headers)
         return response.content
 
+    def text_to_speech_compare(self, text, sources, gender):
+        """
+        :param str text: the text on which tts is to be applied.
+        :param str gender: text to speech supports 'MALE' , 'FEMALE' or 'NEUTRAL'
+        :return:
+            obj: A audio content obj which can be written into a audio file.
+        """
+        body = {'text': text,"sources":sources,"gender":gender}
+        body = json.dumps(body)
+        url = self.base_url + '/text-to-speech/compare'
+        headers = {'ApiKey': self.api_key, 'Content-Type': 'application/json'}
+        response = requests.post(url=url, data=body, headers=headers)
+        return response.content
+    
+
+
     def speech_to_text(self, audio_path, language):
         """
         :param str audio_path: the path of the audio file.
@@ -576,11 +592,24 @@ class DltkAiClient:
             obj: A json obj containing transcript of the audio file.
         """
         body = {'audio': (audio_path, open(audio_path, 'rb'), 'multipart/form-data')}
-        url = self.base_url + '/voice_ai/?language={0}'.format(language)
+        url = self.base_url + '/speech-to-text/'
         headers = {'ApiKey': self.api_key}
         response = requests.post(url=url, files=body, headers=headers).json()
         return response
 
+    def speech_to_text_compare(self, audio_path, sources):
+        """
+        :param str audio_path: the path of the audio file.
+        :return:
+            obj: A json obj containing transcript of the audio file.
+        """
+        body = {'audio': (audio_path, open(audio_path, 'rb'), 'multipart/form-data')}
+        payload = {'sources':sources}
+        url = self.base_url + '/speech-to-text/compare'
+        headers = {'ApiKey': self.api_key}
+        response = requests.post(url=url, files=body, headers=headers,data=payload).json()
+        return response
+
     def translation(self, text, language):
         """
         :param str text: the text on which tts is to be applied.
